/*
 * Copyright (c) 2005-2018 KOM – Multimedia Communications Lab
 *
 * This file is part of Simonstrator.KOM.
 * 
 * Simonstrator.KOM is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 * 
 * PeerfactSim.KOM is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with PeerfactSim.KOM.  If not, see <http://www.gnu.org/licenses/>.
 *
 */


package de.tudarmstadt.maki.simonstrator.api.component.sensor.environment.data;

import de.tudarmstadt.maki.simonstrator.api.Time;
import de.tudarmstadt.maki.simonstrator.api.component.sensor.location.Location;
import de.tudarmstadt.maki.simonstrator.api.component.vehicular.roadnetwork.RoadNetworkEdge;

/**
 * @author Bjoern Bueschke
 * @version 1.0 at 26.03.2018
 *
 */
public class BumpProperty implements RoadProperty {

	private final Location _location;
	private final RoadNetworkEdge _edge;
	private final boolean _bump;
	private long _detectionDate;
	
	public BumpProperty(Location pLocation, RoadNetworkEdge pEdge, boolean pBump) {
		_location = pLocation;
		_edge = pEdge;
		_bump = pBump;
		_detectionDate = Time.getCurrentTime();
	}

	@Override
	public long getDetectionDate() {
		return _detectionDate;
	}

	@Override
	public Location getLocation() {
		return _location;
	}

	@Override
	public RoadNetworkEdge getEdge() {
		return _edge;
	}

	public boolean hasBump() {
		return _bump;
	}

	@Override
	public EnvironmentProperty getDefaultProperty() {
		return new BumpProperty(_location, _edge, false);
	}

	@Override
	public int hashCode() {
		return getEdge().getEdgeID().hashCode();
	}

	@Override
	public boolean equals(Object obj) {
		if (obj instanceof BumpProperty) {
			BumpProperty bumpProperty = (BumpProperty) obj;

			return bumpProperty.getEdge().equals(getEdge()) && (bumpProperty.hasBump() == hasBump());
		}
		return super.equals(obj);
	}

}
