/*
 * Copyright (c) 2005-2010 KOM – Multimedia Communications Lab
 *
 * This file is part of Simonstrator.KOM.
 * 
 * Simonstrator.KOM is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 * 
 * PeerfactSim.KOM is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with PeerfactSim.KOM.  If not, see <http://www.gnu.org/licenses/>.
 *
 */


package de.tudarmstadt.maki.simonstrator.api.component.sensor.environment.data;

import de.tudarmstadt.maki.simonstrator.api.Time;
import de.tudarmstadt.maki.simonstrator.api.component.sensor.location.Location;
import de.tudarmstadt.maki.simonstrator.api.component.vehicular.roadnetwork.RoadNetworkEdge;

/**
 * @author Tobias Meuser (tobias.meuser@kom.tu-darmstadt.de)
 * @version 1.0 at 27.02.2018
 *
 */
public class JamProperty implements RoadProperty {

	private final Location _location;
	private final RoadNetworkEdge _edge;
	private final boolean _jammed;
	private long _detectionDate;
	
	public JamProperty(Location pLocation, RoadNetworkEdge pEdge, boolean pJammed) {
		_location = pLocation;
		_edge = pEdge;
		_jammed = pJammed;
		_detectionDate = Time.getCurrentTime();
	}

	@Override
	public long getDetectionDate() {
		return _detectionDate;
	}

	@Override
	public Location getLocation() {
		return _location;
	}

	@Override
	public RoadNetworkEdge getEdge() {
		return _edge;
	}

	public boolean isJammed() {
		return _jammed;
	}

	@Override
	public EnvironmentProperty getDefaultProperty() {
		return new JamProperty(_location, _edge, false);
	}

	@Override
	public int hashCode() {
		return getEdge().getEdgeID().hashCode();
	}

	@Override
	public boolean equals(Object obj) {
		if (obj instanceof JamProperty) {
			JamProperty jamProperty = (JamProperty) obj;

			return jamProperty.getEdge().equals(getEdge()) && (jamProperty.isJammed() == isJammed());
		}
		return super.equals(obj);
	}

}
